# SMQTK - Detection

## Intent
This package provides interfaces and support for black-box object detection.

## Documentation
Documentation is [hosted on ReadTheDocs.io here](
https://smqtk-detection.readthedocs.io/en/stable/).

You can build the sphinx documentation locally for the most up-to-date
reference:
```bash
# Install dependencies
poetry install
# Navigate to the documentation root.
cd docs
# Build the docs.
poetry run make html
# Open in your favorite browser!
firefox _build/html/index.html
```
